@@ -1,16 +1,22 @@
 #include <distributions/aligned_allocator.hpp>
 #include <distributions/clustering.hpp>
 #include <distributions/common.hpp>
+#include <distributions/mixins.hpp>
+#include <distributions/mixture.hpp>
+#include <distributions/models/bb.hpp>
+#include <distributions/models/bnb.hpp>
 #include <distributions/models/dd.hpp>
 #include <distributions/models/dpd.hpp>
 #include <distributions/models/gp.hpp>
 #include <distributions/models/nich.hpp>
 #include <distributions/random_fwd.hpp>
 #include <distributions/random.hpp>
-#include <distributions/sparse_counter.hpp>
+#include <distributions/sparse.hpp>
 #include <distributions/special.hpp>
-#include <distributions/std_wrapper.hpp>
 #include <distributions/timers.hpp>
+#include <distributions/trivial_hash.hpp>
 #include <distributions/vector.hpp>
 #include <distributions/vector_math.hpp>
+#include <distributions/vendor/fmath.hpp>
+
 int main () { return 0; }
